==> ugene_1.12.3+dfsg.orig.tar.xz: ugene-1.12.3+dfsg.orig/src/plugins/GUITestBase/src/tests/common_scenarios/msa_editor/GTTestsMsaEditor.h <==
/**
 * UGENE - Integrated Bioinformatics Tools.
 * Copyright (C) 2008-2013 UniPro <ugene@unipro.ru>
 * http://ugene.unipro.ru
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA 02110-1301, USA.
 */

#ifndef GTTESTSMSAEDITOR_H
#define GTTESTSMSAEDITOR_H

#include <U2Test/GUITestBase.h>

namespace U2 {

namespace GUITest_common_scenarios_msa_editor {
#undef GUI_TEST_PREFIX
#define GUI_TEST_PREFIX "GUITest_common_scenarios_msa_editor_"

GUI_TEST_CLASS_DECLARATION(test_0001)
GUI_TEST_CLASS_DECLARATION(test_0001_1)
GUI_TEST_CLASS_DECLARATION(test_0001_2)
GUI_TEST_CLASS_DECLARATION(test_0001_3)
GUI_TEST_CLASS_DECLARATION(test_0001_4)

GUI_TEST_CLASS_DECLARATION(test_0002)
GUI_TEST_CLASS_DECLARATION(test_0002_1)
GUI_TEST_CLASS_DECLARATION(test_0002_2)
GUI_TEST_CLASS_DECLARATION(test_0002_3)
GUI_TEST_CLASS_DECLARATION(test_0002_4)

GUI_TEST_CLASS_DECLARATION(test_0003)
GUI_TEST_CLASS_DECLARATION(test_0003_1)
GUI_TEST_CLASS_DECLARATION(test_0003_2)
GUI_TEST_CLASS_DECLARATION(test_0003_3)
GUI_TEST_CLASS_DECLARATION(test_0003_4)

GUI_TEST_CLASS_DECLARATION(test_0004)
GUI_TEST_CLASS_DECLARATION(test_0004_1)
GUI_TEST_CLASS_DECLARATION(test_0004_2)

GUI_TEST_CLASS_DECLARATION(test_0005)
GUI_TEST_CLASS_DECLARATION(test_0005_1)
GUI_TEST_CLASS_DECLARATION(test_0005_2)

GUI_TEST_CLASS_DECLARATION(test_0006)
GUI_TEST_CLASS_DECLARATION(test_0006_1)
GUI_TEST_CLASS_DECLARATION(test_0006_2)

GUI_TEST_CLASS_DECLARATION(test_0007)
GUI_TEST_CLASS_DECLARATION(test_0007_1)
GUI_TEST_CLASS_DECLARATION(test_0007_2)
GUI_TEST_CLASS_DECLARATION(test_0007_3)
GUI_TEST_CLASS_DECLARATION(test_0007_4)

GUI_TEST_CLASS_DECLARATION(test_0008)
GUI_TEST_CLASS_DECLARATION(test_0008_1)
GUI_TEST_CLASS_DECLARATION(test_0008_2)
GUI_TEST_CLASS_DECLARATION(test_0008_3)

GUI_TEST_CLASS_DECLARATION(test_0009)
GUI_TEST_CLASS_DECLARATION(test_0009_1)
GUI_TEST_CLASS_DECLARATION(test_0009_2)

GUI_TEST_CLASS_DECLARATION(test_0010)
GUI_TEST_CLASS_DECLARATION(test_0010_1)
GUI_TEST_CLASS_DECLARATION(test_0010_2)

GUI_TEST_CLASS_DECLARATION(test_0011)
GUI_TEST_CLASS_DECLARATION(test_0011_1)
GUI_TEST_CLASS_DECLARATION(test_0011_2)

GUI_TEST_CLASS_DECLARATION(test_0012)
GUI_TEST_CLASS_DECLARATION(test_0012_1)
GUI_TEST_CLASS_DECLARATION(test_0012_2)

GUI_TEST_CLASS_DECLARATION(test_0013)
GUI_TEST_CLASS_DECLARATION(test_0013_1)
GUI_TEST_CLASS_DECLARATION(test_0013_2)

GUI_TEST_CLASS_DECLARATION(test_0014)
GUI_TEST_CLASS_DECLARATION(test_0014_1)
GUI_TEST_CLASS_DECLARATION(test_0014_2)

GUI_TEST_CLASS_DECLARATION(test_0015)
GUI_TEST_CLASS_DECLARATION(test_0015_1)
GUI_TEST_CLASS_DECLARATION(test_0015_2)

GUI_TEST_CLASS_DECLARATION(test_0016)
GUI_TEST_CLASS_DECLARATION(test_0016_1)
GUI_TEST_CLASS_DECLARATION(test_0016_2)

GUI_TEST_CLASS_DECLARATION(test_0017)
GUI_TEST_CLASS_DECLARATION(test_0017_1)
GUI_TEST_CLASS_DECLARATION(test_0017_2)

GUI_TEST_CLASS_DECLARATION(test_0018)
GUI_TEST_CLASS_DECLARATION(test_0018_1)
GUI_TEST_CLASS_DECLARATION(test_0018_2)

GUI_TEST_CLASS_DECLARATION(test_0019)
GUI_TEST_CLASS_DECLARATION(test_0019_1)
GUI_TEST_CLASS_DECLARATION(test_0019_2)

GUI_TEST_CLASS_DECLARATION(test_0020)
GUI_TEST_CLASS_DECLARATION(test_0020_1)

GUI_TEST_CLASS_DECLARATION(test_0021)
GUI_TEST_CLASS_DECLARATION(test_0021_1)
GUI_TEST_CLASS_DECLARATION(test_0021_2)

GUI_TEST_CLASS_DECLARATION(test_0022)
GUI_TEST_CLASS_DECLARATION(test_0022_1)
GUI_TEST_CLASS_DECLARATION(test_0022_2)

GUI_TEST_CLASS_DECLARATION(test_0023)
GUI_TEST_CLASS_DECLARATION(test_0024)

GUI_TEST_CLASS_DECLARATION(test_0025)
GUI_TEST_CLASS_DECLARATION(test_0025_1)

GUI_TEST_CLASS_DECLARATION(test_0026)
GUI_TEST_CLASS_DECLARATION(test_0026_1)

GUI_TEST_CLASS_DECLARATION(test_0026_2_linux)
GUI_TEST_CLASS_DECLARATION(test_0026_2_windows)

GUI_TEST_CLASS_DECLARATION(test_0027)
GUI_TEST_CLASS_DECLARATION(test_0027_1)

GUI_TEST_CLASS_DECLARATION(test_0028_linux)
GUI_TEST_CLASS_DECLARATION(test_0028_windows)

GUI_TEST_CLASS_DECLARATION(test_0029)
GUI_TEST_CLASS_DECLARATION(test_0029_1)
GUI_TEST_CLASS_DECLARATION(test_0029_2)

GUI_TEST_CLASS_DECLARATION(test_0031)
GUI_TEST_CLASS_DECLARATION(test_0031_1)
GUI_TEST_CLASS_DECLARATION(test_0031_2)
GUI_TEST_CLASS_DECLARATION(test_0031_3)
GUI_TEST_CLASS_DECLARATION(test_0031_4)

GUI_TEST_CLASS_DECLARATION(test_0032)
GUI_TEST_CLASS_DECLARATION(test_0032_1)

GUI_TEST_CLASS_DECLARATION(test_0033)
GUI_TEST_CLASS_DECLARATION(test_0033_1)

GUI_TEST_CLASS_DECLARATION(test_0034)
GUI_TEST_CLASS_DECLARATION(test_0034_1)

GUI_TEST_CLASS_DECLARATION(test_0035)
GUI_TEST_CLASS_DECLARATION(test_0035_1)

GUI_TEST_CLASS_DECLARATION(test_0036)
GUI_TEST_CLASS_DECLARATION(test_0036_1)
GUI_TEST_CLASS_DECLARATION(test_0036_2)
GUI_TEST_CLASS_DECLARATION(test_0036_3)

GUI_TEST_CLASS_DECLARATION(test_0037)
GUI_TEST_CLASS_DECLARATION(test_0037_1)
GUI_TEST_CLASS_DECLARATION(test_0037_2)

GUI_TEST_CLASS_DECLARATION(test_0038)
GUI_TEST_CLASS_DECLARATION(test_0038_1)
GUI_TEST_CLASS_DECLARATION(test_0038_2)
GUI_TEST_CLASS_DECLARATION(test_0038_3)
GUI_TEST_CLASS_DECLARATION(test_0038_4)

GUI_TEST_CLASS_DECLARATION(test_0039)

GUI_TEST_CLASS_DECLARATION(test_0040)

GUI_TEST_CLASS_DECLARATION(test_fake)
#undef GUI_TEST_PREFIX
} // namespace U2

} //namespace

#endif // GTTESTSMSAEDITOR_H

==> ugene_1.25.0+dfsg.orig.tar.xz: ugene-1.25.0/src/plugins/GUITestBase/src/tests/common_scenarios/msa_editor/GTTestsMsaEditor.h <==
/**
 * UGENE - Integrated Bioinformatics Tools.
 * Copyright (C) 2008-2016 UniPro <ugene@unipro.ru>
 * http://ugene.net
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA 02110-1301, USA.
 */

#ifndef GTTESTSMSAEDITOR_H
#define GTTESTSMSAEDITOR_H

#include <U2Test/UGUITestBase.h>

namespace U2 {

namespace GUITest_common_scenarios_msa_editor {
#undef GUI_TEST_SUITE
#define GUI_TEST_SUITE "GUITest_common_scenarios_msa_editor"

GUI_TEST_CLASS_DECLARATION(test_0001)
GUI_TEST_CLASS_DECLARATION(test_0001_1)
GUI_TEST_CLASS_DECLARATION(test_0001_2)
GUI_TEST_CLASS_DECLARATION(test_0001_3)
GUI_TEST_CLASS_DECLARATION(test_0001_4)

GUI_TEST_CLASS_DECLARATION(test_0002)
GUI_TEST_CLASS_DECLARATION(test_0002_1)
GUI_TEST_CLASS_DECLARATION(test_0002_2)
GUI_TEST_CLASS_DECLARATION(test_0002_3)
GUI_TEST_CLASS_DECLARATION(test_0002_4)

GUI_TEST_CLASS_DECLARATION(test_0003)
GUI_TEST_CLASS_DECLARATION(test_0003_1)
GUI_TEST_CLASS_DECLARATION(test_0003_2)
GUI_TEST_CLASS_DECLARATION(test_0003_3)
GUI_TEST_CLASS_DECLARATION(test_0003_4)

GUI_TEST_CLASS_DECLARATION(test_0004)
GUI_TEST_CLASS_DECLARATION(test_0004_1)
GUI_TEST_CLASS_DECLARATION(test_0004_2)

GUI_TEST_CLASS_DECLARATION(test_0005)
GUI_TEST_CLASS_DECLARATION(test_0005_1)
GUI_TEST_CLASS_DECLARATION(test_0005_2)

GUI_TEST_CLASS_DECLARATION(test_0006)
GUI_TEST_CLASS_DECLARATION(test_0006_1)
GUI_TEST_CLASS_DECLARATION(test_0006_2)

GUI_TEST_CLASS_DECLARATION(test_0007)
GUI_TEST_CLASS_DECLARATION(test_0007_1)
GUI_TEST_CLASS_DECLARATION(test_0007_2)
GUI_TEST_CLASS_DECLARATION(test_0007_3)
GUI_TEST_CLASS_DECLARATION(test_0007_4)

GUI_TEST_CLASS_DECLARATION(test_0008)
GUI_TEST_CLASS_DECLARATION(test_0008_1)
GUI_TEST_CLASS_DECLARATION(test_0008_2)
GUI_TEST_CLASS_DECLARATION(test_0008_3)

GUI_TEST_CLASS_DECLARATION(test_0009)
GUI_TEST_CLASS_DECLARATION(test_0009_1)
GUI_TEST_CLASS_DECLARATION(test_0009_2)

GUI_TEST_CLASS_DECLARATION(test_0010)
GUI_TEST_CLASS_DECLARATION(test_0010_1)
GUI_TEST_CLASS_DECLARATION(test_0010_2)

GUI_TEST_CLASS_DECLARATION(test_0011)
GUI_TEST_CLASS_DECLARATION(test_0011_1)
GUI_TEST_CLASS_DECLARATION(test_0011_2)

GUI_TEST_CLASS_DECLARATION(test_0012)
GUI_TEST_CLASS_DECLARATION(test_0012_1)
GUI_TEST_CLASS_DECLARATION(test_0012_2)

GUI_TEST_CLASS_DECLARATION(test_0013)
GUI_TEST_CLASS_DECLARATION(test_0013_1)
GUI_TEST_CLASS_DECLARATION(test_0013_2)

GUI_TEST_CLASS_DECLARATION(test_0014)
GUI_TEST_CLASS_DECLARATION(test_0014_1)
GUI_TEST_CLASS_DECLARATION(test_0014_2)

GUI_TEST_CLASS_DECLARATION(test_0015)
GUI_TEST_CLASS_DECLARATION(test_0015_1)
GUI_TEST_CLASS_DECLARATION(test_0015_2)

GUI_TEST_CLASS_DECLARATION(test_0016)
GUI_TEST_CLASS_DECLARATION(test_0016_1)
GUI_TEST_CLASS_DECLARATION(test_0016_2)

GUI_TEST_CLASS_DECLARATION(test_0017)
GUI_TEST_CLASS_DECLARATION(test_0017_1)
GUI_TEST_CLASS_DECLARATION(test_0017_2)

GUI_TEST_CLASS_DECLARATION(test_0018)
GUI_TEST_CLASS_DECLARATION(test_0018_1)
GUI_TEST_CLASS_DECLARATION(test_0018_2)

GUI_TEST_CLASS_DECLARATION(test_0019)
GUI_TEST_CLASS_DECLARATION(test_0019_1)
GUI_TEST_CLASS_DECLARATION(test_0019_2)

GUI_TEST_CLASS_DECLARATION(test_0020)
GUI_TEST_CLASS_DECLARATION(test_0020_1)

GUI_TEST_CLASS_DECLARATION(test_0021)
GUI_TEST_CLASS_DECLARATION(test_0021_1)
GUI_TEST_CLASS_DECLARATION(test_0021_2)

GUI_TEST_CLASS_DECLARATION(test_0022)
GUI_TEST_CLASS_DECLARATION(test_0022_1)
GUI_TEST_CLASS_DECLARATION(test_0022_2)

GUI_TEST_CLASS_DECLARATION(test_0023)
GUI_TEST_CLASS_DECLARATION(test_0024)

GUI_TEST_CLASS_DECLARATION(test_0025)
GUI_TEST_CLASS_DECLARATION(test_0025_1)

GUI_TEST_CLASS_DECLARATION(test_0026)
GUI_TEST_CLASS_DECLARATION(test_0026_1)

GUI_TEST_CLASS_DECLARATION(test_0026_2_linux)
GUI_TEST_CLASS_DECLARATION(test_0026_2_windows)

GUI_TEST_CLASS_DECLARATION(test_0027)
GUI_TEST_CLASS_DECLARATION(test_0027_1)

GUI_TEST_CLASS_DECLARATION(test_0028_linux)
GUI_TEST_CLASS_DECLARATION(test_0028_windows)

GUI_TEST_CLASS_DECLARATION(test_0029)
GUI_TEST_CLASS_DECLARATION(test_0029_1)
GUI_TEST_CLASS_DECLARATION(test_0029_2)

GUI_TEST_CLASS_DECLARATION(test_0031)
GUI_TEST_CLASS_DECLARATION(test_0031_1)
GUI_TEST_CLASS_DECLARATION(test_0031_2)
GUI_TEST_CLASS_DECLARATION(test_0031_3)
GUI_TEST_CLASS_DECLARATION(test_0031_4)

GUI_TEST_CLASS_DECLARATION(test_0032)
GUI_TEST_CLASS_DECLARATION(test_0032_1)

GUI_TEST_CLASS_DECLARATION(test_0033)
GUI_TEST_CLASS_DECLARATION(test_0033_1)

GUI_TEST_CLASS_DECLARATION(test_0034)
GUI_TEST_CLASS_DECLARATION(test_0034_1)

GUI_TEST_CLASS_DECLARATION(test_0035)
GUI_TEST_CLASS_DECLARATION(test_0035_1)

GUI_TEST_CLASS_DECLARATION(test_0036)
GUI_TEST_CLASS_DECLARATION(test_0036_1)
GUI_TEST_CLASS_DECLARATION(test_0036_2)
GUI_TEST_CLASS_DECLARATION(test_0036_3)

GUI_TEST_CLASS_DECLARATION(test_0037)
GUI_TEST_CLASS_DECLARATION(test_0037_1)
GUI_TEST_CLASS_DECLARATION(test_0037_2)

GUI_TEST_CLASS_DECLARATION(test_0038)
GUI_TEST_CLASS_DECLARATION(test_0038_1)
GUI_TEST_CLASS_DECLARATION(test_0038_2)
GUI_TEST_CLASS_DECLARATION(test_0038_3)
GUI_TEST_CLASS_DECLARATION(test_0038_4)

GUI_TEST_CLASS_DECLARATION(test_0039)
GUI_TEST_CLASS_DECLARATION(test_0039_1)
GUI_TEST_CLASS_DECLARATION(test_0039_2)
GUI_TEST_CLASS_DECLARATION(test_0039_3)
GUI_TEST_CLASS_DECLARATION(test_0039_4)
GUI_TEST_CLASS_DECLARATION(test_0039_5)
GUI_TEST_CLASS_DECLARATION(test_0039_6)
GUI_TEST_CLASS_DECLARATION(test_0039_7)

GUI_TEST_CLASS_DECLARATION(test_0040)

GUI_TEST_CLASS_DECLARATION(test_0041)

GUI_TEST_CLASS_DECLARATION(test_0042)
GUI_TEST_CLASS_DECLARATION(test_0042_1)
GUI_TEST_CLASS_DECLARATION(test_0042_2)
GUI_TEST_CLASS_DECLARATION(test_0043)
GUI_TEST_CLASS_DECLARATION(test_0044)
GUI_TEST_CLASS_DECLARATION(test_0045)
GUI_TEST_CLASS_DECLARATION(test_0045_1)
GUI_TEST_CLASS_DECLARATION(test_0046)
GUI_TEST_CLASS_DECLARATION(test_0047)
GUI_TEST_CLASS_DECLARATION(test_0048)
GUI_TEST_CLASS_DECLARATION(test_0049)

GUI_TEST_CLASS_DECLARATION(test_0050)
GUI_TEST_CLASS_DECLARATION(test_0051)
GUI_TEST_CLASS_DECLARATION(test_0052)

GUI_TEST_CLASS_DECLARATION(test_0053)
GUI_TEST_CLASS_DECLARATION(test_0053_1)
GUI_TEST_CLASS_DECLARATION(test_0053_2)
GUI_TEST_CLASS_DECLARATION(test_0053_3)
GUI_TEST_CLASS_DECLARATION(test_0053_4)
GUI_TEST_CLASS_DECLARATION(test_0053_5)

GUI_TEST_CLASS_DECLARATION(test_0054)
GUI_TEST_CLASS_DECLARATION(test_0054_1)
GUI_TEST_CLASS_DECLARATION(test_0055)
GUI_TEST_CLASS_DECLARATION(test_0056)
GUI_TEST_CLASS_DECLARATION(test_0057)
GUI_TEST_CLASS_DECLARATION(test_0058)
GUI_TEST_CLASS_DECLARATION(test_0059)
GUI_TEST_CLASS_DECLARATION(test_0060)
GUI_TEST_CLASS_DECLARATION(test_0061)
GUI_TEST_CLASS_DECLARATION(test_0062)
GUI_TEST_CLASS_DECLARATION(test_0063)
GUI_TEST_CLASS_DECLARATION(test_0064)
GUI_TEST_CLASS_DECLARATION(test_0065)
GUI_TEST_CLASS_DECLARATION(test_0066)
GUI_TEST_CLASS_DECLARATION(test_0067)
GUI_TEST_CLASS_DECLARATION(test_0068)
GUI_TEST_CLASS_DECLARATION(test_0069)
GUI_TEST_CLASS_DECLARATION(test_0070)
GUI_TEST_CLASS_DECLARATION(test_0071)
GUI_TEST_CLASS_DECLARATION(test_0072)
GUI_TEST_CLASS_DECLARATION(test_0073)
GUI_TEST_CLASS_DECLARATION(test_0074)
GUI_TEST_CLASS_DECLARATION(test_0075)
GUI_TEST_CLASS_DECLARATION(test_0076)
GUI_TEST_CLASS_DECLARATION(test_0077)
GUI_TEST_CLASS_DECLARATION(test_0078)

// alphabet
GUI_TEST_CLASS_DECLARATION(test_0079)
GUI_TEST_CLASS_DECLARATION(test_0080)
GUI_TEST_CLASS_DECLARATION(test_0081)
GUI_TEST_CLASS_DECLARATION(test_0082)
GUI_TEST_CLASS_DECLARATION(test_0083)


GUI_TEST_CLASS_DECLARATION(test_fake)
#undef GUI_TEST_SUITE
} // namespace U2

} //namespace

#endif // GTTESTSMSAEDITOR_H
